fn leads_with_fusable_unary(expr: &Expr<'_>) -> bool
Whether the leftmost operand of expr is a - or ~ unary, following the left spine of binary and ternary expressions so x =- a + 1 (x = (-a) + 1) is caught as well.
expr
-
~
x =- a + 1
x = (-a) + 1